@@ -36,7 +36,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("BatchSendEmail", params)
+            headers = request.headers
+            body = self.call("BatchSendEmail", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.BatchSendEmailResponse()
@@ -64,7 +65,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateEmailAddress", params)
+            headers = request.headers
+            body = self.call("CreateEmailAddress", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateEmailAddressResponse()
@@ -92,7 +94,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateEmailIdentity", params)
+            headers = request.headers
+            body = self.call("CreateEmailIdentity", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateEmailIdentityResponse()
@@ -121,7 +124,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateEmailTemplate", params)
+            headers = request.headers
+            body = self.call("CreateEmailTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateEmailTemplateResponse()
@@ -149,7 +153,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateReceiver", params)
+            headers = request.headers
+            body = self.call("CreateReceiver", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateReceiverResponse()
@@ -177,7 +182,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateReceiverDetail", params)
+            headers = request.headers
+            body = self.call("CreateReceiverDetail", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateReceiverDetailResponse()
@@ -195,6 +201,35 @@ class SesClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateReceiverDetailWithData(self, request):
+        """添加收件人地址附带模板参数
+
+        :param request: Request instance for CreateReceiverDetailWithData.
+        :type request: :class:`tencentcloud.ses.v20201002.models.CreateReceiverDetailWithDataRequest`
+        :rtype: :class:`tencentcloud.ses.v20201002.models.CreateReceiverDetailWithDataResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateReceiverDetailWithData", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateReceiverDetailWithDataResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteBlackList(self, request):
         """邮箱被拉黑之后，用户如果确认收件邮箱有效或者已经处于激活状态，可以从腾讯云地址库中删除该黑名单之后继续投递。
 
@@ -205,7 +240,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteBlackList", params)
+            headers = request.headers
+            body = self.call("DeleteBlackList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteBlackListResponse()
@@ -233,7 +269,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteEmailAddress", params)
+            headers = request.headers
+            body = self.call("DeleteEmailAddress", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteEmailAddressResponse()
@@ -261,7 +298,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteEmailIdentity", params)
+            headers = request.headers
+            body = self.call("DeleteEmailIdentity", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteEmailIdentityResponse()
@@ -289,7 +327,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteEmailTemplate", params)
+            headers = request.headers
+            body = self.call("DeleteEmailTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteEmailTemplateResponse()
@@ -307,6 +346,35 @@ class SesClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteReceiver(self, request):
+        """根据收件id删除收件人列表,同时删除列表中的所有收件邮箱
+
+        :param request: Request instance for DeleteReceiver.
+        :type request: :class:`tencentcloud.ses.v20201002.models.DeleteReceiverRequest`
+        :rtype: :class:`tencentcloud.ses.v20201002.models.DeleteReceiverResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteReceiver", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteReceiverResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def GetEmailIdentity(self, request):
         """获取某个发信域名的配置详情
 
@@ -317,7 +385,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetEmailIdentity", params)
+            headers = request.headers
+            body = self.call("GetEmailIdentity", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetEmailIdentityResponse()
@@ -345,7 +414,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetEmailTemplate", params)
+            headers = request.headers
+            body = self.call("GetEmailTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetEmailTemplateResponse()
@@ -365,6 +435,7 @@ class SesClient(AbstractClient):
 
     def GetSendEmailStatus(self, request):
         """获取邮件发送状态。仅支持查询30天之内的数据
+        默认接口请求频率限制：1次/秒
 
         :param request: Request instance for GetSendEmailStatus.
         :type request: :class:`tencentcloud.ses.v20201002.models.GetSendEmailStatusRequest`
@@ -373,7 +444,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetSendEmailStatus", params)
+            headers = request.headers
+            body = self.call("GetSendEmailStatus", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetSendEmailStatusResponse()
@@ -401,7 +473,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetStatisticsReport", params)
+            headers = request.headers
+            body = self.call("GetStatisticsReport", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetStatisticsReportResponse()
@@ -429,7 +502,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ListBlackEmailAddress", params)
+            headers = request.headers
+            body = self.call("ListBlackEmailAddress", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ListBlackEmailAddressResponse()
@@ -457,7 +531,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ListEmailAddress", params)
+            headers = request.headers
+            body = self.call("ListEmailAddress", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ListEmailAddressResponse()
@@ -485,7 +560,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ListEmailIdentities", params)
+            headers = request.headers
+            body = self.call("ListEmailIdentities", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ListEmailIdentitiesResponse()
@@ -513,7 +589,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ListEmailTemplates", params)
+            headers = request.headers
+            body = self.call("ListEmailTemplates", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ListEmailTemplatesResponse()
@@ -541,7 +618,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ListReceivers", params)
+            headers = request.headers
+            body = self.call("ListReceivers", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ListReceiversResponse()
@@ -569,7 +647,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ListSendTasks", params)
+            headers = request.headers
+            body = self.call("ListSendTasks", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ListSendTasksResponse()
@@ -597,7 +676,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SendEmail", params)
+            headers = request.headers
+            body = self.call("SendEmail", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SendEmailResponse()
@@ -625,7 +705,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdateEmailIdentity", params)
+            headers = request.headers
+            body = self.call("UpdateEmailIdentity", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpdateEmailIdentityResponse()
@@ -653,7 +734,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdateEmailTemplate", params)
+            headers = request.headers
+            body = self.call("UpdateEmailTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpdateEmailTemplateResponse()
